import 'package:change/src/model/change_type.dart';
import 'package:change/src/model/markdown_line.dart';
import 'package:markdown/markdown.dart';

class Collection {
  final Map<ChangeType, List<MarkdownLine>> _map =
      Map.fromIterable(ChangeType.all, value: (_) => <MarkdownLine>[]);

  /// Adds a new change from [text]. The text will be parsed as markdown.
  void addText(ChangeType type, String text) =>
      add(type, MarkdownLine.parse(text));

  /// Adds a new change.
  void add(ChangeType type, MarkdownLine MarkdownLine) {
    _map[type].add(MarkdownLine);
  }

  /// Copies all changes from the [source] collection.
  void copyFrom(Collection source) {
    _map.forEach((type, list) {
      list.addAll(source._map[type]);
    });
  }

  /// Clears all changes
  void clear() {
    _map.values.forEach((element) {
      element.clear();
    });
  }

  List<MarkdownLine> get(ChangeType kind) => _map[kind];

  List<Node> toMarkdown() => _map.entries
      .map((_) => _.value.isNotEmpty
          ? [_title(_.key.name), _entries(_.value)]
          : <Element>[])
      .expand((_) => _)
      .toList();

  Element _title(String text) => Element('h3', [Text(text)]);

  Element _entries(List<MarkdownLine> entries) =>
      Element('ul', entries.map((_) => Element('li', _.nodes)).toList());
}
